package DE_EPAGES::CSVExportImport::UI::CSVExportImport;
use base qw( DE_EPAGES::Presentation::UI::Object );

use strict;
use DE_EPAGES::Core::API::Error qw (Error);
use DE_EPAGES::Core::API::File qw ( GetFileContent );

#==============================================================================
# Event handlers
#==============================================================================
sub getPrivateCSVExportFileName {
    my $self    = shift;
    my $Servlet = shift;
    my $User = $Servlet->user;

    return $User->get('PrivatePath')."/CSVExport.csv";
}

sub getPrivateCSVImportFileName {
    my $self    = shift;
    my $Servlet = shift;
    my $User = $Servlet->user;

    return $User->get('PrivatePath') ."/CSVImport.csv";
}

sub getUnityMediaGalleryArchivePath {
    my $self    = shift;
    my $Servlet = shift;

    return $Servlet->object->child('UnityMediaImportFiles')->get('PublicPath')."/";
}

sub CSVExportImport {
    my $self    = shift;
    my $Servlet = shift;
    my $Object = $Servlet->object;

    my $Form = $Servlet->form->form($Object, 'CSVExportImport');
    $Servlet->form->executeFormError( {
        'Form'       => 'CSVExportImport',
        'Name'       => 'NewImportFile',
        'Reason'     => 'STRING_EMPTY',
    } ) if defined $Form->{'Import'} and not defined $Form->{'NewImportFile'};

    my $CSVExportImportType = $Form->{'CSVExportImportType'};
    if (defined $CSVExportImportType) {
        my $Action = 'CSVExportImport' . $CSVExportImportType;
        $Servlet->doAction($Action);
    } else {
        Error('NoCSVExportImportType');
    }
    return;
}

sub ViewCSVExportResult {
    my $self    = shift;
    my $Servlet = shift;

    my $CSVFileName = $Servlet->params('CSVFileName') ? $Servlet->params('CSVFileName') : 'export';
    my $PathFileName = $self->getPrivateCSVExportFileName($Servlet);

    my $rContent= GetFileContent($PathFileName, {'binary'=>1});
    my $Response = $Servlet->response;
    $Response->content( $$rContent);
    $Response->header( 'Content-Type' => 'application/text',
                       'Content-Disposition' => 'attachment; filename=' . $CSVFileName . '.csv',
                       'Content-Description' => 'csv export file' );
    $Servlet->vars('ExitAfterEvent',1);
    return;
}

1;
