#========================================================================================
# package      DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest
# state        public
#----------------------------------------------------------------------------------------
# description  build the Confianza page and make sure it is valid
#----------------------------------------------------------------------------------------
# example      DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest->new()
#========================================================================================
package DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest;

use strict;
use LWP::UserAgent;
use HTTP::Request;
use DE_EPAGES::ThirdPartyConfig::API::ThirdPartyConfig qw (GetDefaultTimeOut);

my $URL_CO_DIRECTORY = 'http://www.confianzaonline.org/empresas/';

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;

    return $self;
}

#========================================================================================
# function     isValidConfianzaCode
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Success = $Handler->isValidConfianzaCode($ConfianzaCode);
#----------------------------------------------------------------------------------------
# description  Builds the URL for the Specified ConfianzaCode and tries to access it
#----------------------------------------------------------------------------------------
# return       $Result->is_success() | is request successful | boolean
#========================================================================================
sub isValidConfianzaCode {
    my $self = shift;
    my ($ConfianzaCode) = @_;

    my $ConfianzaPage = $URL_CO_DIRECTORY . $ConfianzaCode;

    # testing company page on Confianza Online Server
    my $LwpUserAgent = $self->_createLwpUserAgent();
    $LwpUserAgent->timeout(GetDefaultTimeOut());

    my $Request = HTTP::Request->new(GET => $ConfianzaPage);
    $Request->content_type('application/x-www-form-urlencoded');

    my $Result = $LwpUserAgent->request($Request);
    return $Result->is_success();
}

sub _createLwpUserAgent {
    my $self = shift;

    return LWP::UserAgent->new();
}

1;