#==============================================================================
# package      DE_EPAGES::ConfianzaOnline::UI::Shop
# state        private
#==============================================================================
package DE_EPAGES::ConfianzaOnline::UI::Shop;
use base qw ( DE_EPAGES::Presentation::UI::Object );

use strict;
use DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest;
use DE_EPAGES::Core::API::PerlTools qw ( isValid );

my $URL_CO_DIRECTORY = 'http://www.confianzaonline.org/empresas/';

#========================================================================================
# function     attributeValues
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hhValues = $Handler->attributeValues( $Servlet, $Object, $Class );
#----------------------------------------------------------------------------------------
# description  Overrides the function of package DE_EPAGES::Presentation::UI::Object
#               to perform some changes before saving the form to the database. For details
#               of the SUPER function, see DE_EPAGES::Presentation::UI::Object package.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
# input        $Object | object that specifies the context for formatters. For existing
#                           objects this is the object that is to be saved; for new
#                           objects this may be a direct or indirect parent object.
#                        | object
# input        $Class | class that specifies type and range of the attributes | object
# return       $hCheckedValues | checked form values | refhash
#========================================================================================
sub attributeValues {
    my $self = shift;
    my ($Servlet, $Object, $Class) = @_;

    my $hCheckedValues = $self->_checkSuperFormValues($Servlet, $Object, $Class);

    my $ConfianzaCode = $hCheckedValues->{'Values'}->{'ConfianzaOnlineCode'};

    if (isValid($ConfianzaCode)) {

        my $ConfianzaRequest = $self->_createConfianzaRequest();

        if (not $ConfianzaRequest->isValidConfianzaCode($ConfianzaCode)) {
            $Servlet->form->addFormError({
                'Reason'=> 'ConfianzaOnlineCode',
                'Name'  => 'ConfianzaOnlineCode'
            });
        }
    }
    return $hCheckedValues;
}

sub _checkSuperFormValues {
    my $self = shift;
    my ($Servlet, $Object, $Class) = @_;

    return $self->SUPER::attributeValues($Servlet, $Object, $Class);
}

sub _createConfianzaRequest {
    my $self = shift;

    return DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest->new();
}

1;
