#========================================================================================
# package      DE_EPAGES::ConfianzaOnline::t::unit::ConfianzaRequest
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  unit test for API::ConfianzaRequest
#========================================================================================
package DE_EPAGES::ConfianzaOnline::t::unit::ConfianzaRequest;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest;
use LWP::UserAgent;
use HTTP::Response;
use HTTP::Status qw ( HTTP_OK HTTP_BAD_REQUEST );
use DE_EPAGES::ThirdPartyConfig::API::Constants qw ( TIMEOUT_COMMUNICATION_SCRIPT );
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::More;
use Test::Exception;
use Test::Mockify;
use Test::Mockify::Matcher qw ( Object Number);
use Test::Mockify::Verify qw ( WasCalled );

use feature 'switch';

use strict;

sub test {
    my $self = shift;
    $self->_test_isSuccess();
    $self->_test_isNotSuccess();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub _test_isSuccess {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $HttpResponse = HTTP::Response->new(HTTP_OK);
    my $LwpUserAgent = $self->_createLwpUserAgent($HttpResponse);

    my $SUT = $self->_createSUT($LwpUserAgent);

    my $ConfianzaOnlineCode = 'defined';

    ok($SUT->isValidConfianzaCode($ConfianzaOnlineCode), "$SubTestName - test if isSuccessRequest returns true");

    ok(WasCalled($LwpUserAgent, 'request'), "$SubTestName - test if LwpUserAgent request was called");

    return;
}

sub _test_isNotSuccess {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $HttpResponse = HTTP::Response->new(HTTP_BAD_REQUEST);
    my $LwpUserAgent = $self->_createLwpUserAgent($HttpResponse);

    my $SUT = $self->_createSUT($LwpUserAgent);

    my $ConfianzaOnlineCode = 'defined';

    ok(!$SUT->isValidConfianzaCode($ConfianzaOnlineCode), "$SubTestName - test if isSuccessRequest returns false");

    ok(WasCalled($LwpUserAgent, 'request'), "$SubTestName - test if LwpUserAgent request was called");

    return;
}

sub _createSUT {
    my $self = shift;
    my ($LwpUserAgent) = @_;

    my $aParameterList = [];

    my $MockedSUT = Test::Mockify->new(
        'DE_EPAGES::ConfianzaOnline::API::ConfianzaRequest',
        $aParameterList
    );

    $MockedSUT->mock('_createLwpUserAgent')->when()->thenReturn($LwpUserAgent);

    return $MockedSUT->getMockObject();
}

sub _createLwpUserAgent {
    my $self = shift;
    my ($HttpResponse) = @_;

    my $aParameterList = [];

    my $MockedUserAgent = Test::Mockify->new('LWP::UserAgent', $aParameterList);

    $MockedUserAgent->mock('timeout')->when(Number(TIMEOUT_COMMUNICATION_SCRIPT))->thenReturn(1);
    $MockedUserAgent->mock('request')->when(Object('HTTP::Request'))->thenReturn($HttpResponse);

    return $MockedUserAgent->getMockObject();
}

__PACKAGE__->runScript();

1;
