#========================================================================================
# package      DE_EPAGES::Content::API::Legal::Imprint
# state        public
#----------------------------------------------------------------------------------------
# description  Legal page "Imprint" aka "Contact information".
#========================================================================================
package DE_EPAGES::Content::API::Legal::Imprint;
use base DE_EPAGES::Content::API::Legal::LegalPage;

use strict;

## no critic (ProhibitUnusedPrivateSubroutines)



#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  Constructor
#----------------------------------------------------------------------------------------
# input        $Shop | A shop | DE_EPAGES::Shop::API::Object::Shop
# return       $self | self | DE_EPAGES::Content::API::Legal::Imprint
#========================================================================================
sub new {
    my $class = shift;
    my ($Shop) = @_;
    my $self  = bless {
        'Shop' => $Shop,
    }, $class;
    return $self;
}



sub _getLegalPage {
    my $self = shift;
    my $Shop = $self->{'Shop'};
    return $Shop->get('Imprint');
}



sub _createData {
    my $self = shift;
    my ($hRequestBody) = @_;

    return {
        'Name' => $hRequestBody->{'name'},
        'Title' => $hRequestBody->{'title'},
        'NavigationCaption' => $hRequestBody->{'navigationCaption'},
        'Description' => $hRequestBody->{'shortDescription'},
        'Text' => $hRequestBody->{'description'},
        'Company' => $hRequestBody->{'company'},
        'ContactPerson' => $hRequestBody->{'contactPerson'},
        'ContactPersonSynonym' => $hRequestBody->{'contactPersonJobTitle'},
        'Address' => $hRequestBody->{'address'},
        'Phone' => $hRequestBody->{'phone'},
        'Fax' => $hRequestBody->{'fax'},
        'Email' => $hRequestBody->{'email'},
    };
}



sub _getLegalData {
    my $self = shift;
    my ($LegalPage, $LanguageID) = @_;

    my $Shop = $LegalPage->getSite();

    my $Name = $LegalPage->get('Name', $LanguageID);
    my $Title = $LegalPage->get('Title', $LanguageID);
    my $NavigationCaption = $LegalPage->get('NavigationCaption', $LanguageID);
    my $ShortDescription = $LegalPage->get('Description', $LanguageID);
    my $Description = $LegalPage->get('Text', $LanguageID);
    my $Company = $LegalPage->get('Company', $LanguageID);
    my $ContactPerson = $LegalPage->get('ContactPerson', $LanguageID);
    my $ContactPersonJobTitle = $LegalPage->get('ContactPersonSynonym', $LanguageID);
    my $Address = $LegalPage->get('Address', $LanguageID);
    my $Phone = $LegalPage->get('Phone', $LanguageID);
    my $Fax = $LegalPage->get('Fax', $LanguageID);
    my $Email = $Shop->get('IsUnityRegistered') ? $Shop->get('Address')->get('EMail', $LanguageID)
        : $LegalPage->get('Email', $LanguageID);

    my $hLegalData = {
        'name' => $Name,
        'title' => $Title,
        'navigationCaption' => $NavigationCaption,
        'shortDescription' => $ShortDescription,
        'description' => $Description,
        'company' => $Company,
        'contactPerson' => $ContactPerson,
        'contactPersonJobTitle' => $ContactPersonJobTitle,
        'address' => $Address,
        'phone' => $Phone,
        'fax' => $Fax,
        'email' => $Email,
    };

    return $hLegalData;
}

1;