#========================================================================================
# package      DE_EPAGES::Content::t::LegalContentUnityResources_get
# base         DE_EPAGES::Shop::API::TestImportXML
# state        public
#----------------------------------------------------------------------------------------
# description  Integration test for get methods in the legal content Unity resources.
#========================================================================================
package DE_EPAGES::Content::t::LegalContentUnityResources_get;
use base DE_EPAGES::Shop::API::TestImportXML;

use DE_EPAGES::Content::API::Resource::LegalInformationSummaryResource;
use DE_EPAGES::Content::API::Resource::CustomerInformationResource;
use DE_EPAGES::Content::API::Resource::ShippingInformationResource;
use DE_EPAGES::Content::API::Resource::TermsAndConditionsResource;
use DE_EPAGES::Content::API::Resource::PrivacyPolicyResource;
use DE_EPAGES::Content::API::Resource::ImprintResource;
use Test::More;

use strict;

sub shopAlias {
    return 'LegalPagesUnityTestShop';
}

sub importXMLPath {
    return 'ShopXMLs/Shop_for_LegalContentUnityResources_Get_test.xml';
}

sub test {
    my $self = shift;

    $self->test_get_summary();

    $self->test_get_imprint();
    $self->test_get_customerInformation();
    $self->test_get_privacyPolicy();
    $self->test_get_termsAndConditions();
    $self->test_get_shippingInformation();

    done_testing();
}

my $LocaleID = 'en_GB';

sub test_get_summary {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::LegalInformationSummaryResource->new();

    my $hData = $Resource->get($Shop, $LocaleID);

    my $hExpectedSummary = $self->_createExpectedSummary();
    is_deeply($hData, $hExpectedSummary, "$SubTestName - test if expected summary was returned");

    return;
}

sub test_get_imprint {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::ImprintResource->new();

    my $hData = $Resource->get($Shop, $LocaleID);

    is($hData->{'name'}, 'Contact information test', "$SubTestName - test if name in returned data is correct");
    is($hData->{'email'}, 't.tester@epages.com', "$SubTestName - test if eMail in returned data is correct");
    is($hData->{'navigationCaption'}, 'contact info caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hData->{'description'}, 'this page contains contact infos for the customer', "$SubTestName - test if description in returned data is correct");

    return;
}

sub test_get_customerInformation { # aka "rights of withdrawal"
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::CustomerInformationResource->new();

    my $hData = $Resource->get($Shop, $LocaleID);

    is($hData->{'name'}, 'rights of withdrawal test', "$SubTestName - test if name in returned data is correct");
    is($hData->{'navigationCaption'}, 'customer info caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hData->{'description'}, 'this page contains infos for the customer', "$SubTestName - test if description in returned data is correct");

    return;
}

sub test_get_privacyPolicy {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::PrivacyPolicyResource->new();

    my $hData = $Resource->get($Shop, $LocaleID);

    is($hData->{'name'}, 'privacy policy test', "$SubTestName - test if name in returned data is correct");
    is($hData->{'navigationCaption'}, 'privacy policy caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hData->{'description'}, 'this page contains the privacy policy of the shop', "$SubTestName - test if description in returned data is correct");

    return;
}

sub test_get_termsAndConditions {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::TermsAndConditionsResource->new();

    my $hData = $Resource->get($Shop, $LocaleID);

    is($hData->{'name'}, 'tests and conditions', "$SubTestName - test if name in returned data is correct");
    is($hData->{'navigationCaption'}, 'terms and conditions caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hData->{'description'}, 'this page contains the terms and conditions of the shop', "$SubTestName - test if description in returned data is correct");

    return;
}

sub test_get_shippingInformation {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::ShippingInformationResource->new();

    my $hData = $Resource->get($Shop, $LocaleID);

    is($hData->{'name'}, 'shipping information test', "$SubTestName - test if name in returned data is correct");
    is($hData->{'navigationCaption'}, 'shipping info caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hData->{'description'}, 'this page contains the shipping information of the shop', "$SubTestName - test if description in returned data is correct");

    return;
}

sub _createExpectedSummary {
    return {
        'shippingInformation' => {
            'name' => 'shipping information test'
        },
        'rightsOfWithdrawal' => {
            'name' => 'rights of withdrawal test'
        },
        'termsAndConditions' => {
            'name' => 'tests and conditions'
        },
        'privacyPolicy' => {
            'name' => 'privacy policy test'
        },
        'contactInformation' => {
            'name' => 'Contact information test'
        }
    };
}

__PACKAGE__->runScript();

1;
