#========================================================================================
# package      DE_EPAGES::Content::t::LegalContentUnityResources_put
# base         DE_EPAGES::Shop::API::TestImportXML
# state        public
#----------------------------------------------------------------------------------------
# description  Integration test for put methods in the legal content Unity resources.
#========================================================================================
package DE_EPAGES::Content::t::LegalContentUnityResources_put;
use base DE_EPAGES::Shop::API::TestImportXML;

use DE_EPAGES::Content::API::Resource::CustomerInformationResource;
use DE_EPAGES::Content::API::Resource::ShippingInformationResource;
use DE_EPAGES::Content::API::Resource::TermsAndConditionsResource;
use DE_EPAGES::Content::API::Resource::PrivacyPolicyResource;
use DE_EPAGES::Content::API::Resource::ImprintResource;
use Test::More;

use strict;

sub shopAlias {
    return 'LegalPagesUnityTestShop';
}

sub importXMLPath {
    return 'ShopXMLs/Shop_for_LegalContentUnityResources_Put_test.xml';
}

sub test {
    my $self = shift;

    $self->test_put_imprint();
    $self->test_put_customerInformation();
    $self->test_put_privacyPolicy();
    $self->test_put_termsAndConditions();
    $self->test_put_shippingInformation();

    done_testing();
}

my $LocaleID = 'en_GB';
my $LanguageID = 2; # language id of english

sub test_put_imprint {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::ImprintResource->new();

    my $hRequestData = {
        'name' => 'Contact information test',
        'navigationCaption' => 'contact info caption',
        'description' => 'this page contains contact infos for the customer'
    };

    my $hUpdatedData = $Resource->put($Shop, $hRequestData, $LocaleID);

    is($hUpdatedData->{'name'}, 'Contact information test', "$SubTestName - test if name in returned data is correct");
    is($hUpdatedData->{'navigationCaption'}, 'contact info caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hUpdatedData->{'description'}, 'this page contains contact infos for the customer', "$SubTestName - test if description in returned data is correct");
    my $Imprint = $Shop->get('Imprint');
    is($Imprint->get('Name', $LanguageID), 'Contact information test', "$SubTestName - test if name in imprint was correctly updated");
    is($Imprint->get('NavigationCaption', $LanguageID), 'contact info caption', "$SubTestName - test if navigation caption in imprint was correctly updated");
    is($Imprint->get('Text', $LanguageID), 'this page contains contact infos for the customer', "$SubTestName - test if description in imprint was correctly updated");

    return;
}

sub test_put_customerInformation { # aka "rights of withdrawal"
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::CustomerInformationResource->new();

    my $hRequestData = {
        'name' => 'rights of withdrawal test',
        'navigationCaption' => 'customer info caption',
        'description' => 'this page contains infos for the customer'
    };

    my $hUpdatedData = $Resource->put($Shop, $hRequestData, $LocaleID);

    is($hUpdatedData->{'name'}, 'rights of withdrawal test', "$SubTestName - test if name in returned data is correct");
    is($hUpdatedData->{'navigationCaption'}, 'customer info caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hUpdatedData->{'description'}, 'this page contains infos for the customer', "$SubTestName - test if description in returned data is correct");
    my $CustomerInformation = $Shop->get('CustomerInformation');
    is($CustomerInformation->get('Name', $LanguageID), 'rights of withdrawal test', "$SubTestName - test if name in customer information page  was correctly updated");
    is($CustomerInformation->get('NavigationCaption', $LanguageID), 'customer info caption', "$SubTestName - test if navigation caption in customer information page  was correctly updated");
    is($CustomerInformation->get('Text', $LanguageID), 'this page contains infos for the customer', "$SubTestName - test if description in customer information page was correctly updated");

    return;
}

sub test_put_privacyPolicy {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::PrivacyPolicyResource->new();

    my $hRequestData = {
        'name' => 'privacy policy test',
        'navigationCaption' => 'privacy policy caption',
        'description' => 'this page contains the privacy policy of the shop'
    };

    my $hUpdatedData = $Resource->put($Shop, $hRequestData, $LocaleID);

    is($hUpdatedData->{'name'}, 'privacy policy test', "$SubTestName - test if name in returned data is correct");
    is($hUpdatedData->{'navigationCaption'}, 'privacy policy caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hUpdatedData->{'description'}, 'this page contains the privacy policy of the shop', "$SubTestName - test if description in returned data is correct");
    my $PrivacyPolicy = $Shop->get('PrivacyPolicy');
    is($PrivacyPolicy->get('Name', $LanguageID), 'privacy policy test', "$SubTestName - test if name in privacy policy page  was correctly updated");
    is($PrivacyPolicy->get('NavigationCaption', $LanguageID), 'privacy policy caption', "$SubTestName - test if navigation caption in privacy policy page  was correctly updated");
    is($PrivacyPolicy->get('Text', $LanguageID), 'this page contains the privacy policy of the shop', "$SubTestName - test if description in privacy policy page was correctly updated");

    return;
}

sub test_put_termsAndConditions {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::TermsAndConditionsResource->new();

    my $hRequestData = {
        'name' => 'tests and conditions',
        'navigationCaption' => 'terms and conditions caption',
        'description' => 'this page contains the terms and conditions of the shop'
    };

    my $hUpdatedData = $Resource->put($Shop, $hRequestData, $LocaleID);

    is($hUpdatedData->{'name'}, 'tests and conditions', "$SubTestName - test if name in returned data is correct");
    is($hUpdatedData->{'navigationCaption'}, 'terms and conditions caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hUpdatedData->{'description'}, 'this page contains the terms and conditions of the shop', "$SubTestName - test if description in returned data is correct");
    my $TermsAndConditions = $Shop->get('TermsAndConditions');
    is($TermsAndConditions->get('Name', $LanguageID), 'tests and conditions', "$SubTestName - test if name in terms and conditions page  was correctly updated");
    is($TermsAndConditions->get('NavigationCaption', $LanguageID), 'terms and conditions caption', "$SubTestName - test if navigation caption in terms and conditions page  was correctly updated");
    is($TermsAndConditions->get('Text', $LanguageID), 'this page contains the terms and conditions of the shop', "$SubTestName - test if description in terms and conditions page was correctly updated");

    return;
}

sub test_put_shippingInformation {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->shop();
    my $Resource = DE_EPAGES::Content::API::Resource::ShippingInformationResource->new();

    my $hRequestData = {
        'name' => 'shipping information test',
        'navigationCaption' => 'shipping info caption',
        'description' => 'this page contains the shipping information of the shop',
    };

    my $hUpdatedData = $Resource->put($Shop, $hRequestData, $LocaleID);

    is($hUpdatedData->{'name'}, 'shipping information test', "$SubTestName - test if name in returned data is correct");
    is($hUpdatedData->{'navigationCaption'}, 'shipping info caption', "$SubTestName - test if navigation caption in returned data is correct");
    is($hUpdatedData->{'description'}, 'this page contains the shipping information of the shop', "$SubTestName - test if description in returned data is correct");
    my $ShippingInformation = $Shop->get('ShippingAndPaymentInformation');
    is($ShippingInformation->get('Name', $LanguageID), 'shipping information test', "$SubTestName - test if name in shipping information page  was correctly updated");
    is($ShippingInformation->get('NavigationCaption', $LanguageID), 'shipping info caption', "$SubTestName - test if navigation caption in shipping information page  was correctly updated");
    is($ShippingInformation->get('Text', $LanguageID), 'this page contains the shipping information of the shop', "$SubTestName - test if description in shipping information page was correctly updated");

    return;
}


__PACKAGE__->runScript();

1;
