#========================================================================================
# package      DE_EPAGES::Content::t::unit::LegalImprint
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Content::API::Legal::Imprint.
#========================================================================================
package DE_EPAGES::Content::t::unit::LegalImprint;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Content::API::Legal::Imprint;
use DE_EPAGES::Test::Mock::EpagesObject;
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_get();
    $self->test_update();
    $self->test_undef();

    done_testing();
}



sub test_get {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hImprintData = {
        'Name' => 'test name',
        'Title' => 'test title',
        'NavigationCaption' => 'test nav caption',
        'Description' => 'test desc',
        'Text' => 'test text',
        'Company' => 'test company',
        'ContactPerson' => 'test contact person',
        'ContactPersonSynonym' => 'test contact person synonym',
        'Address' => 'test address',
        'Phone' => 'test phone',
        'Fax' => 'test fax',
        'Email' => 'test email',
    };

    my $LegalImprint = $self->_createLegalImprint($hImprintData);

    ok($LegalImprint->isDefined(), "$SubTestName - test if shop has imprint.");

    my $hExpectedData = $self->_createData();
    is_deeply($LegalImprint->get(), $hExpectedData, "$SubTestName - test if expected data was returned.");
}



sub test_update {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LegalImprint = $self->_createLegalImprint({});

    ok($LegalImprint->isDefined(), "$SubTestName - test if shop has imprint.");

    $LegalImprint->update($self->_createData());

    my $hExpectedData = $self->_createData();
    is_deeply($LegalImprint->get(), $hExpectedData, "$SubTestName - test if expected data was returned.");
}



sub test_undef {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LegalImprint = $self->_createUndefLegalImprint({});

    is($LegalImprint->isDefined(), '', "$SubTestName - test if shop has no imprint.");
}



sub _createLegalImprint {
    my $self = shift;
    my ($hImprintData) = @_;

    my $Imprint = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Content::API::Object::Imprint', $hImprintData);

    my $Shop = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
        'Imprint' => $Imprint,
        'IsUnityRegistered' => undef
    });
    $Imprint->set({'Site' => $Shop});
    return DE_EPAGES::Content::API::Legal::Imprint->new($Shop);
}



sub _createUndefLegalImprint {
    my $self = shift;
    my ($hImprintData) = @_;

    my $Shop = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
        'Imprint' => undef,
    });
    return DE_EPAGES::Content::API::Legal::Imprint->new($Shop);
}



sub _createData {
    my $self = shift;
    return {
        'name' => 'test name',
        'title' => 'test title',
        'navigationCaption' => 'test nav caption',
        'shortDescription' => 'test desc',
        'description' => 'test text',
        'company' => 'test company',
        'contactPerson' => 'test contact person',
        'contactPersonJobTitle' => 'test contact person synonym',
        'address' => 'test address',
        'phone' => 'test phone',
        'fax' => 'test fax',
        'email' => 'test email',
    };
}

__PACKAGE__->runScript();