#========================================================================================
# package      DE_EPAGES::Content::t::unit::LegalInformationSummary
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Content::API::Legal::LegalInformationSummary.
#========================================================================================
package DE_EPAGES::Content::t::unit::LegalInformationSummary;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Content::API::Legal::LegalInformationSummary;
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockery;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_LegalInformationSummary();

    done_testing();
}

sub test_LegalInformationSummary {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mocks = $self->_createMocks();
    my $Shop = $Mocks->get('Shop');
    my $Imprint = $Mocks->get('Imprint');
    $Imprint->set({'Site' => $Shop});

    my $LegalInformationSummary = DE_EPAGES::Content::API::Legal::LegalInformationSummary->new($Shop);
    my $hSummary = $LegalInformationSummary->get();

    my $hExpectedSummary = $self->_createExpectedSummary();
    is_deeply($hSummary, $hExpectedSummary, "$SubTestName - test if expected summary was returned.");
}

sub _createMocks {
    my $self = shift;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('Shop', ['CustomerInformation', 'Imprint', 'PrivacyPolicy', 'TermsAndConditions', 'ShippingAndPaymentInformation'], sub {
        my ($CustomerInformation, $Imprint, $PrivacyPolicy, $TermsAndConditions,$ShippingAndPaymentInformation) = @_;
        return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {
            'CustomerInformation' => $CustomerInformation,
            'Imprint' => $Imprint,
            'PrivacyPolicy' => $PrivacyPolicy,
            'TermsAndConditions' => $TermsAndConditions,
            'ShippingAndPaymentInformation' => $ShippingAndPaymentInformation,
            'IsUnityRegistered' => undef
        });
    });

    $Mockery->register('CustomerInformation', [], sub {
        return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Content::API::Object::CustomerInformation', {
            'Name' => 'test customer information',
            'Title' => '',
            'NavigationCaption' => '',
            'Description' => '',
            'Text' => '',
        });
    });

    $Mockery->register('Imprint', [], sub {
        return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Content::API::Object::Imprint', {
            'Name' => 'test imprint',
            'Title' => '',
            'NavigationCaption' => '',
            'Description' => '',
            'Text' => '',
            'Company' => '',
            'ContactPerson' => '',
            'ContactPersonSynonym' => '',
            'Address' => '',
            'Phone' => '',
            'Fax' => '',
            'Email' => '',
        });
    });

    $Mockery->register('PrivacyPolicy', [], sub {
        return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Content::API::Object::PrivacyPolicy', {
            'Name' => 'test privacy policy',
            'Title' => '',
            'NavigationCaption' => '',
            'Description' => '',
            'Text' => '',
        });
    });

    $Mockery->register('TermsAndConditions', [], sub {
        return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Content::API::Object::TermsAndConditions', {
            'Name' => 'test terms and conditions',
            'Title' => '',
            'NavigationCaption' => '',
            'Description' => '',
            'Text' => '',
        });
    });

    $Mockery->register('ShippingAndPaymentInformation', [], sub {
            return DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::Content::API::Object::ShippingAndPaymentInformation', {
                    'Name' => 'test shipping and payment information',
                    'Title' => '',
                    'NavigationCaption' => '',
                    'Description' => '',
                    'Text' => '',
                });
        });

    return $Mockery->assemble();
}

sub _createExpectedSummary {
    my $self = shift;
    return {
        'rightsOfWithdrawal' => {
            'name' => 'test customer information',
        },
        'contactInformation' => {
            'name' => 'test imprint',
        },
        'privacyPolicy' => {
            'name' => 'test privacy policy',
        },
        'termsAndConditions' => {
            'name' => 'test terms and conditions',
        },
        'shippingInformation' => {
            'name' => 'test shipping and payment information',
        }
    };
}

__PACKAGE__->runScript();
