#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::Name
# state        public
# description  Name element for the DHL Versenden shipping label request builder
#========================================================================================
package DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::Name;

use DE_EPAGES::Core::API::PerlTools qw ( isValid );
use DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::LeafNodeHelper;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Name = DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::Name->new();
#----------------------------------------------------------------------------------------
# description  Object contructor.
#----------------------------------------------------------------------------------------
# return       $Name | DHL Versenden name element object | object
#========================================================================================
sub new {
    my $class = shift;

    my $self  = bless {}, $class;

    return $self;
}

#========================================================================================
# function     assemble
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hName = $self->assemble($ShopAddress);
#----------------------------------------------------------------------------------------
# description  Create the hash with name data for the Shipping label request
#----------------------------------------------------------------------------------------
# input        $ShopAddress | shop address object | object
# return       $hName | DHL Versenden name element | ref.hash
#========================================================================================
sub assemble {
    my $self = shift;
    my ($ShopAddress) = @_;

    my $LeafNodeHelper = DE_EPAGES::DHLIntraship::API::SOAP::ShippingLabelRequest::LeafNodeHelper->new();
    my $hName = {};
    my $Company = $ShopAddress->get('Company');

    if (isValid($Company)) {
        $LeafNodeHelper->addLeaf('name1', $Company);
        $LeafNodeHelper->addLeaf('name2', $ShopAddress->get('FullName'));

        $hName->{'name2'} = $LeafNodeHelper->getLeaf('name2');
    } else {
        $LeafNodeHelper->addLeaf('name1', $ShopAddress->get('FullName'));
    }
    $hName->{'name1'} = $LeafNodeHelper->getLeaf('name1');

    my @Warnings = @{$LeafNodeHelper->getWarnings()};

    return {
        'nodeData' => {
            'Name' => {
                %{$hName}
                # no optional name3 (second part of the company name not needed)
            }
        },
        'nodeWarnings' => \@Warnings
    };
}

1;