#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::TLE::AddressValidation
# state        public
#----------------------------------------------------------------------------------------
# description  TLE for Address Validation
#========================================================================================
package DE_EPAGES::DHLIntraship::API::TLE::AddressValidation;

use DE_EPAGES::DHLIntraship::API::AddressValidationMerchant;
use DE_EPAGES::Object::API::Factory qw ( LoadObject );

use strict;

#========================================================================================
# function     RegisterHandlerProc
# state        private
#----------------------------------------------------------------------------------------
# syntax       $RegisterHandlerProc( $hParams );
#----------------------------------------------------------------------------------------
# description  this function register this attribute handle on the processor via hook
#               function on hook TLEProcessorRegistration
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments keys :
#               <ul>
#                   <li>Processor - tle processor - object
#               </ul> | ref.hash
#========================================================================================
sub RegisterHandlerProc {
    my ($Params) = @_;

    __PACKAGE__->new()->register( $Params->{'Processor'} );
    return;
}

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler = new DE_EPAGES::Object::API::TLE::IncludeTemplateHandler;
# example      my $PrefixHandler  = new DE_EPAGES::Object::API::TLE::IncludeTemplateHandler;
#----------------------------------------------------------------------------------------
# description  create a new handler
#----------------------------------------------------------------------------------------
# input        %args | args | array
#----------------------------------------------------------------------------------------
# return       $Handler | blessed object | object
#========================================================================================
sub new {
    my $class = shift;
    my %args  = @_;
    my $self  = bless \%args, $class;
    return $self;
}
#========================================================================================
# function     register
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler->register( $Processor );
#----------------------------------------------------------------------------------------
# description  Registers this handle on the processor
#----------------------------------------------------------------------------------------
# input        $Processor | tle processor | object
#========================================================================================
sub register {
    my $self = shift;
    my ($Processor) = @_;
    $Processor->registerHandler('FunctionHandler', $self, 'SHOW_DHLINTRASHIP_WARNINGS');
    return;
}

#========================================================================================
# function     SHOW_DHLINTRASHIP_WARNINGS
# state        public
#----------------------------------------------------------------------------------------
# syntax       SHOW_DHLINTRASHIP_WARNINGS( $Processor, $aParams );
#----------------------------------------------------------------------------------------
# description  provides a list with missing Attributes from the ShopAddress
#----------------------------------------------------------------------------------------
# input        $Processor | tle processor | object
# input        $aParams | List of Parameters | refarray
# return       $ReturnValue | a list with Warning for UI | refarray
#========================================================================================
sub SHOW_DHLINTRASHIP_WARNINGS {
    my $self = shift;
    my ($Processor, $aParams) = @_;

    my ($ShopAddressID) = @{$aParams};
    my $ShopAddress = LoadObject($ShopAddressID);
    my $AddressValidation = DE_EPAGES::DHLIntraship::API::AddressValidationMerchant->new($ShopAddress);
    my $NotProcessableWarningStates = $AddressValidation->getNotProcessableWarningStates();
    my $aWarnings = $AddressValidation->getStatesAsWarning($NotProcessableWarningStates);

    return $aWarnings;
}

1;