#========================================================================================
# package      DE_EPAGES::Moneybookers::API::Tools
# state        public
#----------------------------------------------------------------------------------------
# description  Useful functions for this cartridge.
#========================================================================================
package DE_EPAGES::Moneybookers::API::Tools;

use DE_EPAGES::Core::API::Log qw ( LogContext );
use DE_EPAGES::Core::API::TestParameter qw ( TestObject );

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  Class constructor.
#----------------------------------------------------------------------------------------
# return       $self | self | object
#========================================================================================
sub new {
    my $class = shift;
    my $self = bless {}, $class;
    return $self;
}

#========================================================================================
# function     LogShopContext
# state        public
#----------------------------------------------------------------------------------------
# syntax       LogShopContext( $ShopObject, $MethodName, $FunctionPointer );
#----------------------------------------------------------------------------------------
# description  it allows to include shop context into logs for the specified function pointer
#----------------------------------------------------------------------------------------
# input        $ShopObject | an epages object that belongs to a shop | object
# input        $MethodPath | path name of the method | string
# input        $FunctionPointer | reference pointer to a code | ref.code
#========================================================================================
sub LogShopContext {
    my $self = shift;
    my ($ShopObject, $MethodName, $FunctionPointer) = @_;

    TestObject('DE_EPAGES::Shop::API::Object::Shop', $ShopObject);
    my $Shop = $ShopObject->getSite();

    LogContext(
            {
                'Shop ID' => $Shop->id(),
                'Shop Alias' => $Shop->alias(),
                'EntryPoint' => $MethodName
            },
            $FunctionPointer
    );
    return;
}

1;
