#==============================================================================
# package      DE_EPAGES::Order::API::Constants
# state        public
# description  Constants for cartridge Order
#==============================================================================
package DE_EPAGES::Order::API::Constants;
use base Exporter;

use strict;
use DE_EPAGES::Core::API::EpagesConfig qw ( EpagesConfig );

our @EXPORT_OK = qw(
    CLASS_MAP
    COUNTRYID_ITALY
    FISCALCODE_LIMIT
    ORDER_STATUS_ATTRIBUTES
    NO_SPLIT_SHIPPING_TAX
    NO_SPLIT_PAYMENT_TAX
    CLASSICCHECKOUT
    MULTISTEPCHECKOUT
    UNITY_PASSWORD_ACTIONS
    MAX_DAYS_OF_LATEST_ORDER_FOR_UNITY_MIGRATION
    PDF_DENSITY
);

#========================================================================================
# global       CLASS_MAP | Maps attribute names to class aliases:<ul>
#                   <li>LineItems      => LineItemSales
#                   <li>SalesDiscounts => LineItemSalesDiscount
#                   <li>Discounts      => LineItemDiscount
#                   <li>Taxes          => LineItemTax
#                   <li>TaxesDigital   => LineItemTaxDigital
#                   <li>Shipping       => LineItemShipping
#                   <li>Payment        => LineItemPayment
#                   <li>PaymentDiscount=> LineItemPaymentDiscount
#                   <li>Orders         => CustomerOrder
#                   <li>PrePayments    => LineItemPrePayment
#               </ul> | ref.hash
#========================================================================================
use constant CLASS_MAP => {
    'Positions'      => 'LineItem',
    'LineItems'      => 'LineItemSales',
    'SalesDiscounts' => 'LineItemSalesDiscount',
    'Discounts'      => 'LineItemDiscount',
    'Taxes'          => 'LineItemTax',
    'TaxesDigital'   => 'LineItemTaxDigital',
    'Shipping'       => 'LineItemShipping',
    'Payment'        => 'LineItemPayment',
    'PaymentDiscount'=> 'LineItemPaymentDiscount',
    'Orders'         => 'CustomerOrder',
    'Statics'        => 'LineItemStatic',
    'PrePayments'    => 'LineItemPrePayment',
};

#========================================================================================
# global       ORDER_STATUS_ATTRIBUTES | list of order status attributes:
#                       ViewedOn CancelledOn, ...
#                       | list
#========================================================================================
use constant ORDER_STATUS_ATTRIBUTES => qw(ViewedOn CancelledOn InProcessOn PendingOn
    ReadyForShippingOn PartlyDispatchedOn DispatchedOn ShippedOn PartlyInvoicedOn
    InvoicedOn PartlyPaidOn PaidOn ClosedOn ArchivedOn ReturnedOn);

#========================================================================================
# global       NO_SPLIT_SHIPPING_TAX | list of countries where the shipping methods tax
#                                       is independend from the product tax
#                                       e.g. product 7% tax and product with 19% tax:
#                                       shipping tax is not splitted in 7% and 19%
#                                       the tax from the shipping method is used
#                       | list of country Code2 codes
#========================================================================================
use constant NO_SPLIT_SHIPPING_TAX => qw( FR GB ES NL IT PT AU NZ );

#========================================================================================
# global       NO_SPLIT_PAYMENT_TAX | list of countries where the payment methods tax
#                                       is independend from the product tax
#                                       e.g. product 7% tax and product with 19% tax:
#                                       payment tax is not splitted in 7% and 19%
#                                       the tax from the payment method is used
#                       | list of country Code2 codes
#========================================================================================
use constant NO_SPLIT_PAYMENT_TAX => qw( FR GB ES NL IT PT AU NZ );

#========================================================================================
# global       FISCALCODE_LIMIT | limit for the italian fiscal code; if the grand total
#                                       value of a basket goes over this value the fiscal
#                                       code is mandatory for an italian order on an
#                                       italian shop
#                       | int
#========================================================================================
use constant FISCALCODE_LIMIT => 3600;

#========================================================================================
# global       COUNTRYID_ITALY | country id for italy
#                       | int
#========================================================================================
use constant COUNTRYID_ITALY => 380;

use constant CLASSICCHECKOUT => 0;
use constant MULTISTEPCHECKOUT => 1;

#========================================================================================
# global       UNITY_PASSWORD_ACTIONS | View actions needed for the password reset in
#                   Unity shops, these should be redirected to the epages6 storefront
#                       | ref.array.string
#========================================================================================
use constant UNITY_PASSWORD_ACTIONS => [qw( UnityViewLostPassword UnityViewChangeLostPassword )];

#========================================================================================
# global       MAX_DAYS_OF_LATEST_ORDER_FOR_UNITY_MIGRATION | maximum amount of days of
#                       the latest order of a shop that is still allowed for a Unity
#                       migration
#========================================================================================
sub MAX_DAYS_OF_LATEST_ORDER_FOR_UNITY_MIGRATION() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get('DE_EPAGES::Order', 'MaxDaysOfLatestOrderForUnityMigration', 30);
}

#========================================================================================
# global       PDF_DENSITY | density for pdf print | int
#========================================================================================
use constant PDF_DENSITY => 96;

1;
