package DE_EPAGES::Presentation::t::Redirect;
use base DE_EPAGES::Database::API::Test;

use Test::More;

use strict;

use DE_EPAGES::Database::API::Connection qw (RunOnStore);
use DE_EPAGES::Presentation::UI::Object;
use DE_EPAGES::Core::API::Script qw (RunScript);

use DE_EPAGES::Presentation::t::RedirectServletMock;
use DE_EPAGES::Presentation::t::RedirectShopMock;

our $Uri    = 'my-cool-shop.intern.epages.de/epages/Wurstshop';
our $Locale = 'en_GB';
our $Path   = '/Shops/Wurstshop';

sub test {
    my $self = shift;

    RunOnStore(
                Store => "Store",
                Sub   => sub {
                    testRedirectToDomain();
                    testRedirectToMobile();
                    testRedirectToStorefront();
                    done_testing();
                }
    );

    return;
}

sub testRedirectToDomain {
    my $ServletMock = DE_EPAGES::Presentation::t::RedirectServletMock->new();
    my $ShopMock    = DE_EPAGES::Presentation::t::RedirectShopMock->new();
    $ShopMock->setDomainName("my-sexy-domain.com");
    $ServletMock->setMockShop($ShopMock);
    
    my $Location    = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 0);
    is("http://my-sexy-domain.com", $Location, "Redirect to domain name with http successful.");
    
    $Location = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 1);
    is("https://my-sexy-domain.com", $Location, "Redirect to domain name with https successful.");
}

sub testRedirectToMobile {
    my $ViewAction  = 'MyFancyViewAction';

    my $ServletMock = DE_EPAGES::Presentation::t::RedirectServletMock->new();
    my $ShopMock    = DE_EPAGES::Presentation::t::RedirectShopMock->new();

    $ServletMock->setIsMobile('1');
    $ServletMock->setMockShop($ShopMock);

    my $Location    = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 0);
    is('http://' . $Uri . '.mobile/' . $Locale . '/?ObjectPath=' . $Path, $Location, 'Redirect to mobile url with http successful.');

    $Location = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 1);
    is('https://' . $Uri . '.mobile/' . $Locale . '/?ObjectPath=' . $Path, $Location, 'Redirect to mobile url with https successful.');

    $ServletMock->setViewAction($ViewAction);

    $Location    = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 0);
    is('http://' . $Uri . '.mobile/' . $Locale . '/?ObjectPath=' . $Path . '&ViewAction=' . $ViewAction, $Location, 'Redirect to mobile url with http and custom viewaction successful.');
    
    $Location = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 1);
    is('https://' . $Uri . '.mobile/' . $Locale . '/?ObjectPath=' . $Path . '&ViewAction=' . $ViewAction, $Location, 'Redirect to mobile url with https and custom viewaction successful.');
}

sub testRedirectToStorefront {
    my $ViewAction  = 'MyFancyViewAction';

    my $ServletMock = DE_EPAGES::Presentation::t::RedirectServletMock->new();
    my $ShopMock    = DE_EPAGES::Presentation::t::RedirectShopMock->new();

    $ServletMock->setMockShop($ShopMock);

    my $Location    = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 0);
    is('http://' . $Uri . '.sf/' . $Locale . '/?ObjectPath=' . $Path, $Location, 'Redirect to sf url with http successful.');

    $Location = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 1);
    is('https://' . $Uri . '.sf/' . $Locale . '/?ObjectPath=' . $Path, $Location, 'Redirect to sf url with https successful.');

    $ServletMock->setViewAction($ViewAction);

    $Location    = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 0);
    is('http://' . $Uri . '.sf/' . $Locale . '/?ObjectPath=' . $Path . '&ViewAction=' . $ViewAction, $Location, 'Redirect to sf url with http and custom viewaction successful.');
    
    $Location = DE_EPAGES::Presentation::UI::Object->getRedirectLocation($ServletMock, 1);
    is('https://' . $Uri . '.sf/' . $Locale . '/?ObjectPath=' . $Path . '&ViewAction=' . $ViewAction, $Location, 'Redirect to sf url with https and custom viewaction successful.');
}

RunScript( Sub => \&test );

1;
