use strict;
use feature 'say';

use Getopt::Long;
use DE_EPAGES::Core::API::Error qw( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Object::API::Factory qw( LoadObjectByPath );

sub Main {

    my $Password;
    my $Help;
    my $ShopAlias;
    my $StoreName;

    GetOptions(
        'help'       => \$Help,
        'passwd=s'      => \$Password,
        'storename=s'   => \$StoreName,
        'shopalias=s'   => \$ShopAlias,
    );

    usage() if $Help;

    unless ($ShopAlias) {
        print STDERR "Missing parameter -shopalias.\n\n";
        usage();
    }

    unless ($StoreName) {
        print STDERR "Missing parameter -storename.\n\n";
        usage();
    }

    # find the shop in sitedb
    RunOnStore(
        Store => $StoreName,
        DBPassword => $Password,
        Sub   => sub {
            my $Shop = LoadObjectByPath('/Shops')->child($ShopAlias);

            eval {
                $Shop->updateUnityShop($Shop->{'Attributes'});
            };
            if (ExistsError()) {
                say 'Synchronizing the shop status to Unity failed.';
                say 'Error message: ' . GetError()->message;
            } else {
                say 'Synchronizing the shop status to Unity was successful.';
            }
        }
    );
}

sub usage {
    print <<END_USAGE;
Usage:
    perl $0 [options] [flags]

options:
    -passwd                      database user password     (optional)
    -storename                   the name of the Store      (required)
    -shopalias                   the shopalias of the shop  (required)

flags:
    -help       show the command line options

Example:
    perl $0 -storename <Store> -shopalias <ShopAlias>
END_USAGE
    exit 2;
}

RunScript('Sub' => \&Main);

