#========================================================================================
# package      DE_EPAGES::WebService::Servlet::Soap
# base         DE_EPAGES::WebInterface::Servlet::BaseServlet
# state        public
#----------------------------------------------------------------------------------------
# description  implements dispatching of SOAP requests to cartridge modules.
#========================================================================================
package DE_EPAGES::WebService::Servlet::Soap;
use base qw( DE_EPAGES::WebInterface::Servlet::BaseServlet Exporter );
use strict;

our @EXPORT_OK = qw( GetSoapServer );

use DE_EPAGES::Core::API::Error qw (Error);
use DE_EPAGES::Core::API::Log qw( GetLog );
use DE_EPAGES::Database::API::Config qw( DatabaseRedirect );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Object::API::Language;
use DE_EPAGES::WebInterface::API::ApplicationServer qw( GetAppServer );
use DE_EPAGES::WebService::API::SoapServer;
use DE_EPAGES::WebService::API::Serializer;

our $SOAP_SERVER;

#define the used SOAP::Serializer
sub SOAP_SERIALIZER {DE_EPAGES::WebService::API::Serializer->new};

sub handleRequest {
    my $self = shift;

    # connect to store or site
    my $StoreName = $self->storeName;

    my $AppServer = GetAppServer;
    my $RemoteAddr = $AppServer->serverVariables->{'REMOTE_ADDR'};
    my $Redirect = DatabaseRedirect($StoreName, undef, $RemoteAddr);
    Error('DatabaseRedirect', {
        'StoreName' => $StoreName,
    }) if $Redirect;

    RunOnStore( 'Store' => $StoreName, 'Sub' => sub {
        $self->response->header('X-Store', $StoreName);
        GetLog->debug('connected to store ', $StoreName);

        #reset default LanguageID
        local $DE_EPAGES::Object::API::Language::LANGUAGEID = undef;

        local $SOAP_SERVER = DE_EPAGES::WebService::API::SoapServer->new;
        my $SOAP_SERIALIZER = SOAP_SERIALIZER();
        $self->serializer( $SOAP_SERIALIZER ) if $SOAP_SERIALIZER;
        $SOAP_SERVER->handle( $self, $self->request, $self->response );
    });

    GetLog->debug('disconnected');
    return;
}

#========================================================================================
# function     serializer
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Serializer = serializer();
#----------------------------------------------------------------------------------------
# description  set Serializer of this SOAP::Server object
#               or returns current SOAP::Serializer if no Serializer passed
#----------------------------------------------------------------------------------------
# input        $Serializer | SOAP server object (optional) | WebService::API::Serializer (based on SOAP::Serializer)
#----------------------------------------------------------------------------------------
# return       $Serializer | SOAP server object | SOAP::Serializer
#========================================================================================
sub serializer {
    my $self = shift;
    my ( $Serializer ) = @_;
    return GetSoapServer()->serializer($Serializer);
}

#========================================================================================
# function     GetSoapServer
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Server = GetSoapServer();
#----------------------------------------------------------------------------------------
# description  returns the current SOAP::Lite server instance. Call this function only
#               within a SOAP request.
#----------------------------------------------------------------------------------------
# return       $Server | SOAP server object | SharedLib::SOAP::SoapServer
#========================================================================================
sub GetSoapServer {
    return $SOAP_SERVER;
}


1;
